# TinySOM
The `tinysom` package is yet another Self-Organising Maps (SOM) library on a rectangular grid.

## Versions
`0.1.6` Changed dot product metric to cosine similarity; fixed SOM_cluster class definition; fixed bubble and linear neighbourhood kernels.
`0.1.5` *Not used*
`0.1.4` Specify neighbourhood kernel weight at Rmax instead of Rmax itself.
`0.1.3` Minor bug fix and code tidying.
`0.1.2` Added dot product metric and docstring tidying.
`0.1.1` Add SOM_cluster classs and code tidying.
`0.1.0` First release
